
from src.replacers.ner_replacer import NERReplacer
from src.annotations import NameAnnotation, SurnameAnnotation, DateAnnotation, CityAnnotation
from src.dictionaries.morphosyntactic.pl_ner import PlNERMorphosyntacticDictionary

def test_ner_replacer():
    dictionary = PlNERMorphosyntacticDictionary(list=[
        (NameAnnotation, "Andrzej", "Andrzej", "a"),
        (NameAnnotation, "Kasi", "Kasia", "b"),
        (SurnameAnnotation, "Kowalowi", "Kowal", "a"),
        (SurnameAnnotation, "Kowal", "Kowal", "b"),
    ], always_replace=False)
    
    text = "Ala Brzeszczot urodziła sie 05.05.2005 we Wrocławiu"
    detections = [
        (0, 3, NameAnnotation(morpho_tag="a")), 
        (4, 14, SurnameAnnotation(morpho_tag="b")),
        (28, 38, DateAnnotation()),
        (42, 51, CityAnnotation(morpho_tag="c")),
    ]
    
    replacer = NERReplacer(dictionary)
    
    result = replacer.replace(text, detections)
    
    expected_text = "Andrzej Kowal urodziła sie 05.05.2005 we Wrocławiu"
    exptected_detections_left = [
        (27, 37, DateAnnotation()),
        (41, 50, CityAnnotation(morpho_tag="c")),
    ]
    
    assert result == (expected_text, exptected_detections_left)